#!/bin/awk -f
# This awk script reformats the stdout output from w_scan into the tv_conf.xml format
# The variableis tunertype & analog must be passed in as a command line argument
#
# Example call: nawk -F'|' -f genTVconfFile.awk tunertype="QAM" analog=false w_scan.stdout > tv_conf.xml
BEGIN{
OFS="";
print "<tvconf version=\"2\">\n<channels>";
}
{
if($0 ~ /^[^#]/)
{
  enabled="true";

  if(analog)
  {
    name=$2;
    freq=$9*1000;
    input="";
    norm=""; 

    id = "A" freq; 
    extra = tunertype "|" freq "|"  "A|" input "|" norm "|";
  }
  else
  {
    #tv_ra = $1;
    name=$2;
    vpid=$3;
    apids=$4;
    ttypid=$5;
    program=$6;
    streamid=$7;
    frontend=$8;
    freq=$9*1000;
    symbolrate=$10;
    #pol=$11;
    fec=$12 "/" $15;
    inversion=$13;
    constell=$14;
    bandwidth=$16;
    transmode=$17;
    guard=$18;
    hier=$19;
    number=$20;
    #subpids=$21;
    #category=$22;
    #nid=$23;

    if(name ~ /^service*/)
      name="Service  " program; 

    id = "D" freq "." program;
    tunerUsed = tunertype;

    if(frontend=="Atsc")
    {
      if(tunertype == "MGT")
        tunerUsed = "Atsc"

      if(constell == "108")
        modulation = "8VSB";
      else if(constell == "116")
        modulation = "16VSB";
      else 
      {
        # If it's not 108 or 116, then it's QAM
        #modulation = constell "QAM";
        modulation = constell "VSB"; # Where does the VSB come from?

        if(tunertype == "MGT")
          tunerUsed = "QAM"
      }
    }
    else if (frontend == "Cable") 
    { 
      # DVB-C, QAM
      modulation = constell "QAM";

      if(tunertype == "MGT")
        tunerUsed = "DVB-C"
    }
    else if (frontend == "Terrestrial") 
    { 
      # DVB-T
      if(tunertype == "MGT")
        tunerUsed = "QAM"

      if(constell== "8")
      {
        if(tunertype == "MGT")
          tunerUsed = "DVB-T"

        modulation = "8QPSK";
      }
      else if(constell == "-1")
        modulation = "QAM";
      else
        modulation = constell "QAM";
    }

    extra = tunerUsed "|" freq "|D|" vpid "|" apids "|" ttypid "|" program "|" modulation "|" frontend "|" symbolrate "|" fec "|" inversion "|" bandwidth "|" transmode "|" hier "|" guard;
    # replace commas with semicolns
    gsub(/\,/,";",extra);
  }
  print "<channel number=\"", number, "\" name=\"", name, "\" id=\"", id, "\" enabled=\"", enabled, "\" extra=\"", extra, "\"/>";
}}
END{
  print "</channels>\n</tvconf>";
}

