#!/bin/bash

# This script will run the TV scanner and produce the same tv_conf.xml file that
# the truetouch code does
#
# comandline arguments:
# -da=<0=digital, 1=analog>
# -ca=<0=cable, 1=antenna>
# -cc=<country code>
# -i=<0=no inversion, 1=use inversion>
# -h 	display help
# Process command line arguments
is_analog=0
is_antenna=0
country_code="us"
inversion=1
while :; do
  case $1 in
    -h|-\?|--help) # call "show_help" function
      echo "This script will run the TV scanner and produce the same tv_conf.xml file that the truetouch code does."
      echo "Command Line arguments:"
      echo " -da=<0=digital, 1=analog>"
      echo " -ca=<0=cable, 1=antenna>"
      echo " -cc=<country code>"
      echo " -i=<0=no inversion, 1=use inversion> "
      echo " -h    display help" 
      exit
      ;;
    -da) # digital or analog flag
      if [ -n "$2" ]
      then
        is_analog=$2
        shift
      else
        printf 'ERROR: "-da requires a non-empty option argument.\n' >&2
        exit 1 
      fi
      ;;
    -ca) # cable or antenna flag
      if [ -n "$2" ]
      then
        is_antenna=$2
        shift
      else
        printf 'ERROR: "-ca requires a non-empty option argument.\n' >&2
        exit 1
      fi
      ;;
    -cc) # country code
      if [ -n "$2" ] 
      then
        country_code=$2
        shift
      else
        printf 'ERROR: "-cc requires a non-empty option argument.\n' >&2
        exit 1
      fi
      ;;
    -i) # inversion
      if [ -n "$2" ] 
      then
        inversion=$2
        shift
      else
        printf 'ERROR: "-i requires a non-empty option argument.\n' >&2
        exit 1
      fi
      ;;
    *) # default case: if no more options, then break out of the loop
      break
  esac
  shift
done

# retrieve tuner type from the system
tvTunerType=$(/usr/local/bin/truetouch/scripts/tunertype.sh)

# To generate the countryTunerTypes.txt file if it does not exist, execute the command:
#    nawk -F"[:;\"]" '{if($0 ~ /List*/) print $3, $11;}' /home/true/veracity/touch/qml/Television/TelevisionRegionList.qml >countryTunerTypes.txt

# Retrieve the tuner type from the country code
nawkCmd="{if( \$1 == \"$country_code\" ) print \$2}"
tunerType=$(nawk "$nawkCmd" countryTunerTypes.txt)
echo "Country tuner type is $tunerType"

# Modify tuner type for antenna vs. cable and generate the appropriate arguments for w_scan
if [ "$tunerType" == "DMB" ]
then
  tunerType="DTMB"
fi
if [ "$tunerType" == "ISDB" ]
then
  tunerType="ISDB-T"
fi

aa_arg=""
if [ "$tvTunerType" == "DVB-T2" ]
then
  a_arg="-a 2"
  tunerType=$tvTunerType
fi

if [ "$tunerType" = "ATSC" -o "$tunerType" == "QAM" ]
then
  f_arg="-f a"
  if [ "$is_antenna" == 0 ]
  then
    f_arg="$f_arg -A 2"
    tunerType="QAM"
  fi
else  # DVB, ISDB, or other
  if [ "$is_antenna" == 0 ]
  then
    f_arg="-f c"
    if [ "$tunerType" == "DVB" ]
    then
      tunerType="$tunerType-C"
    fi    
   else
    f_arg="-f t"
    if [ $tunerType == "DVB" ]
    then
      tunerType="$tunerType-T"
    fi
  fi
fi

# Exclude encripted signals
e_arg=""
if [ "$tunerType" != "ISDB-T" ]
then
  e_arg="-E 0"
fi

# Set delsys for ISDB/DTMB
d_arg=""
if [ "$tunerType" == "ISDB-T" -o "$tunerType" == "DTMB" ]
then
  d_arg="-d"
fi

# Run w_scan and capture output
outfile_base="w_scan_out"

echo "country_code= $country_code, is_analog=$is_analog, is_antenna=$is_antenna, tunerType=$tunerType tvTunerType=$tvTunerType"
echo "running : w_scan -c $country_code -k -i 1 -t 3 $f_arg $a_arg $e_arg -R 0 $e_arg 2>$outfile_base.stderr 1>$outfile_base.stdout"
w_scan -c $country_code -k -i $inversion -t 3 $f_arg $a_arg $e_arg -R 0 $e_arg 2>$outfile_base.stderr 1>$outfile_base.stdout

# Reformat the output to the xml format
outfilename="tv_conf.xml"

nawk -F'|' -f genTVconfFile.awk tunertype="$tunerType" analog="$is_analog" "$outfile_base".stdout > "$outfilename" 

echo "Finished writing $outfilename"

